Get RDP option analytics
RDPGetOptionAnalytics.Rd`r lifecycle::badge("defunct")`
This function required a Python connection and has been removed. Use the official LSEG Data Library for Python (lseg-data) directly for option analytics.
RDPGetOptionAnalytics.Rd`r lifecycle::badge("defunct")`
This function required a Python connection and has been removed. Use the official LSEG Data Library for Python (lseg-data) directly for option analytics.