Skip to contents

Returns only the data portion as a data.table, avoiding the recycling warning that occurs when the data and error frames have different row counts.

Usage

as.data.table.EikonResult(x, ...)

Arguments

x

An EikonResult object.

...

Passed to data.table::as.data.table().

Value

A data.table.